# Changelog

This page lists the key changes made between consecutive versions of PySLSQP.
A more detailed description of major changes between releases can be found
in [`RELEASE_NOTES.md`](https://github.com/anugrahjo/PySLSQP/blob/main/release_notes.md) 
in the project root directory.

***********************************
## Version 0.1.3 (December 5, 2024)

- Improve performance (multifold) with compiler optimization
- Update citation and include the published paper

***********************************
## Version 0.1.2 (November 24, 2024)

- Add support for NumPy 2.x
- Update PySLSQP software paper

***********************************
## Version 0.1.1 (October 13, 2024)

- Add support for Windows OS (cloud tested and wheels made available on PyPI) 
- More precise timing with perf_counter()
- Fix swapped printing of average function and derivative evaluation times in final results
- Minor updates to documentation
- Add PySLSQP software paper to the repository

***********************************
## Version 0.1.0 (June 2, 2024)

- Initial release of PySLSQP